@@ -6,20 +6,63 @@ package Module::Build;
 # OS-specific modules don't do anything either - most of the work is
 # done in Module::Build::Base.
 
-use 5.006;
 use strict;
-use warnings;
 use File::Spec ();
 use File::Path ();
 use File::Basename ();
-use Perl::OSType ();
 
 use Module::Build::Base;
 
-our @ISA = qw(Module::Build::Base);
-our $VERSION = '0.42_35';
+use vars qw($VERSION @ISA);
+@ISA = qw(Module::Build::Base);
+$VERSION = '0.2805_01';
 $VERSION = eval $VERSION;
 
+# Okay, this is the brute-force method of finding out what kind of
+# platform we're on.  I don't know of a systematic way.  These values
+# came from the latest (bleadperl) perlport.pod.
+
+my %OSTYPES = qw(
+		 aix       Unix
+		 bsdos     Unix
+		 dgux      Unix
+		 dynixptx  Unix
+		 freebsd   Unix
+		 linux     Unix
+		 hpux      Unix
+		 irix      Unix
+		 darwin    Unix
+		 machten   Unix
+		 next      Unix
+		 openbsd   Unix
+		 netbsd    Unix
+		 dec_osf   Unix
+		 svr4      Unix
+		 svr5      Unix
+		 sco_sv    Unix
+		 unicos    Unix
+		 unicosmk  Unix
+		 solaris   Unix
+		 sunos     Unix
+		 cygwin    Unix
+		 os2       Unix
+		 
+		 dos       Windows
+		 MSWin32   Windows
+
+		 os390     EBCDIC
+		 os400     EBCDIC
+		 posix-bc  EBCDIC
+		 vmesa     EBCDIC
+
+		 MacOS     MacOS
+		 VMS       VMS
+		 VOS       VOS
+		 riscos    RiscOS
+		 amigaos   Amiga
+		 mpeix     MPEiX
+		);
+
 # Inserts the given module into the @ISA hierarchy between
 # Module::Build and its immediate parent
 sub _interpose_module {
@@ -41,33 +84,25 @@ sub _interpose_module {
 if (grep {-e File::Spec->catfile($_, qw(Module Build Platform), $^O) . '.pm'} @INC) {
   __PACKAGE__->_interpose_module("Module::Build::Platform::$^O");
 
-} elsif ( my $ostype = os_type() ) {
-  __PACKAGE__->_interpose_module("Module::Build::Platform::$ostype");
+} elsif (exists $OSTYPES{$^O}) {
+  __PACKAGE__->_interpose_module("Module::Build::Platform::$OSTYPES{$^O}");
 
 } else {
   warn "Unknown OS type '$^O' - using default settings\n";
 }
 
-sub os_type { return Perl::OSType::os_type() }
-
-sub is_vmsish { return Perl::OSType::is_os_type('VMS') }
-sub is_windowsish { return Perl::OSType::is_os_type('Windows') }
-sub is_unixish { return Perl::OSType::is_os_type('Unix') }
+sub os_type { $OSTYPES{$^O} }
 
 1;
 
 __END__
 
-=for :stopwords
-bindoc binhtml destdir distcheck distclean distdir distmeta distsign disttest
-fakeinstall html installdirs installsitebin installsitescript installvendorbin
-installvendorscript libdoc libhtml pardist ppd ppmdist realclean skipcheck
-testall testcover testdb testpod testpodcoverage versioninstall
 
 =head1 NAME
 
 Module::Build - Build and install Perl modules
 
+
 =head1 SYNOPSIS
 
 Standard process for building & installing modules:
@@ -91,12 +126,16 @@ the "./" notation, you can do this:
 C<Module::Build> is a system for building, testing, and installing
 Perl modules.  It is meant to be an alternative to
 C<ExtUtils::MakeMaker>.  Developers may alter the behavior of the
-module through subclassing.  It also does not require a C<make> on your
-system - most of the C<Module::Build> code is pure-perl and written in a
-very cross-platform way.
+module through subclassing in a much more straightforward way than
+with C<MakeMaker>.  It also does not require a C<make> on your system
+- most of the C<Module::Build> code is pure-perl and written in a very
+cross-platform way.  In fact, you don't even need a shell, so even
+platforms like MacOS (traditional) can use it fairly easily.  Its only
+prerequisites are modules that are included with perl 5.6.0, and it
+works fine on perl 5.005 if you can install a few additional modules.
 
-See L</"COMPARISON"> for more comparisons between C<Module::Build> and
-other installer tools.
+See L<"MOTIVATIONS"> for more comparisons between C<ExtUtils::MakeMaker>
+and C<Module::Build>.
 
 To install C<Module::Build>, and any other module that uses
 C<Module::Build> for its installation process, do the following:
@@ -110,32 +149,30 @@ This illustrates initial configuration and the running of three
 'actions'.  In this case the actions run are 'build' (the default
 action), 'test', and 'install'.  Other actions defined so far include:
 
-  build                          manifest
-  clean                          manifest_skip
-  code                           manpages
-  config_data                    pardist
-  diff                           ppd
-  dist                           ppmdist
-  distcheck                      prereq_data
-  distclean                      prereq_report
-  distdir                        pure_install
-  distinstall                    realclean
-  distmeta                       retest
-  distsign                       skipcheck
-  disttest                       test
-  docs                           testall
-  fakeinstall                    testcover
-  help                           testdb
-  html                           testpod
-  install                        testpodcoverage
-  installdeps                    versioninstall
+  build                          install     
+  clean                          manifest    
+  code                           manpages    
+  config_data                    ppd         
+  diff                           ppmdist     
+  dist                           prereq_report
+  distcheck                      pure_install
+  distclean                      realclean   
+  distdir                        retest      
+  distmeta                       skipcheck   
+  distsign                       test        
+  disttest                       testcover   
+  docs                           testdb      
+  fakeinstall                    testpod     
+  help                           testpodcoverage
+  html                           versioninstall
+
 
 You can run the 'help' action for a complete list of actions.
 
 
 =head1 GUIDE TO DOCUMENTATION
 
-The documentation for C<Module::Build> is broken up into sections:
+The documentation for C<Module::Build> is broken up into three sections:
 
 =over
 
@@ -182,8 +219,10 @@ C<Build test verbose=1>), in which case their values last only for the
 lifetime of that command.  Per-action command line parameters take
 precedence over parameters specified at C<perl Build.PL> time.
 
-The build process also relies heavily on the C<Config.pm> module.
-If the user wishes to override any of the
+The build process also relies heavily on the C<Config.pm> module, and
+all the key=value pairs in C<Config.pm> are available in
+
+C<< $self->{config} >>.  If the user wishes to override any of the
 values in C<Config.pm>, she may specify them like so:
 
   perl Build.PL --config cc=gcc --config ld=gcc
@@ -199,7 +238,7 @@ The following build actions are provided by default.
 If you run the C<Build> script without any arguments, it runs the
 C<build> action, which in turn runs the C<code> and C<docs> actions.
 
-This is analogous to the C<MakeMaker> I<make all> target.
+This is analogous to the MakeMaker 'make all' target.
 
 =item clean
 
@@ -213,7 +252,7 @@ C<_build/> directory and the C<Build> script itself).
 
 [version 0.20]
 
-This action builds your code base.
+This action builds your codebase.
 
 By default it just creates a C<blib/> directory and copies any C<.pm>
 and C<.pod> files from your C<lib/> directory into the C<blib/>
@@ -260,9 +299,10 @@ module for source distribution through a medium like CPAN.  It will create a
 tarball of the files listed in F<MANIFEST> and compress the tarball using
 GZIP compression.
 
-By default, this action will use the C<Archive::Tar> module. However, you can
-force it to use binary "tar" and "gzip" executables by supplying an explicit
-C<tar> (and optional C<gzip>) parameter:
+By default, this action will use the external C<tar> and C<gzip>
+executables on Unix-like platforms, and the C<Archive::Tar> module
+elsewhere.  However, you can force it to use whatever executable you
+want by supplying an explicit C<tar> (and optional C<gzip>) parameter:
 
   ./Build dist --tar C:\path\to\tar.exe --gzip C:\path\to\zip.exe
 
@@ -271,7 +311,7 @@ C<tar> (and optional C<gzip>) parameter:
 [version 0.05]
 
 Reports which files are in the build directory but not in the
-F<MANIFEST> file, and vice versa.  (See L</manifest> for details.)
+F<MANIFEST> file, and vice versa.  (See L<manifest> for details.)
 
 =item distclean
 
@@ -288,31 +328,26 @@ Creates a "distribution directory" named C<$dist_name-$dist_version>
 copies all the files listed in the F<MANIFEST> file to that directory.
 This directory is what the distribution tarball is created from.
 
-=item distinstall
-
-[version 0.37]
-
-Performs the 'distdir' action, then switches into that directory and runs a
-C<perl Build.PL>, followed by the 'build' and 'install' actions in that
-directory.  Use PERL_MB_OPT or F<.modulebuildrc> to set options that should be
-applied during subprocesses
-
 =item distmeta
 
 [version 0.21]
 
 Creates the F<META.yml> file that describes the distribution.
 
-F<META.yml> is a file containing various bits of I<metadata> about the
+F<META.yml> is a file containing various bits of "metadata" about the
 distribution.  The metadata includes the distribution name, version,
 abstract, prerequisites, license, and various other data about the
-distribution.  This file is created as F<META.yml> in a simplified YAML format.
+distribution.  This file is created as F<META.yml> in YAML format.
+It is recommended that the C<YAML> module be installed to create it.
+If the C<YAML> module is not installed, an internal module supplied
+with Module::Build will be used to write the META.yml file, and this
+will most likely be fine.
 
 F<META.yml> file must also be listed in F<MANIFEST> - if it's not, a
 warning will be issued.
 
-The current version of the F<META.yml> specification can be found
-on CPAN as L<CPAN::Meta::Spec>.
+The current version of the F<META.yml> specification can be found at
+L<http://module-build.sourceforge.net/META-spec-v1.2.html>
 
 =item distsign
 
@@ -326,23 +361,21 @@ MANIFEST.
 
 [version 0.05]
 
-Performs the 'distdir' action, then switches into that directory and runs a
-C<perl Build.PL>, followed by the 'build' and 'test' actions in that directory.
-Use PERL_MB_OPT or F<.modulebuildrc> to set options that should be applied
-during subprocesses
-
+Performs the 'distdir' action, then switches into that directory and
+runs a C<perl Build.PL>, followed by the 'build' and 'test' actions in
+that directory.
 
 =item docs
 
 [version 0.20]
 
-This will generate documentation (e.g. Unix man pages and HTML
+This will generate documentation (e.g. Unix man pages and html
 documents) for any installable items under B<blib/> that
 contain POD.  If there are no C<bindoc> or C<libdoc> installation
 targets defined (as will be the case on systems that don't support
 Unix manpages) no action is taken for manpages.  If there are no
 C<binhtml> or C<libhtml> installation targets defined no action is
-taken for HTML documents.
+taken for html documents.
 
 =item fakeinstall
 
@@ -375,18 +408,12 @@ C<Config.pm>.  You can also supply or override install paths on the
 command line by specifying C<install_path> values for the C<binhtml>
 and/or C<libhtml> installation targets.
 
-With an optional C<html_links> argument set to a false value, you can
-skip the search for other documentation to link to, because that can
-waste a lot of time if there aren't any links to generate anyway:
-
-  ./Build html --html_links 0
-
 =item install
 
 [version 0.01]
 
 This action will use C<ExtUtils::Install> to install the files from
-C<blib/> into the system.  See L</"INSTALL PATHS">
+C<blib/> into the system.  See L<"INSTALL PATHS">
 for details about how Module::Build determines where to install
 things, and how to influence this process.
 
@@ -401,24 +428,6 @@ This can be a good idea, as it helps prevent multiple versions of a
 module from being present on your system, which can be a confusing
 situation indeed.
 
-=item installdeps
-
-[version 0.36]
-
-This action will use the C<cpan_client> parameter as a command to install
-missing prerequisites.  You will be prompted whether to install
-optional dependencies.
-
-The C<cpan_client> option defaults to 'cpan' but can be set as an option or in
-F<.modulebuildrc>.  It must be a shell command that takes a list of modules to
-install as arguments (e.g. 'cpanp -i' for CPANPLUS).  If the program part is a
-relative path (e.g. 'cpan' or 'cpanp'), it will be located relative to the perl
-program that executed Build.PL.
-
-  /opt/perl/5.8.9/bin/perl Build.PL
-  ./Build installdeps --cpan_client 'cpanp -i'
-  # installs to 5.8.9
-
 =item manifest
 
 [version 0.05]
@@ -443,17 +452,9 @@ add your own stuff to it:
   ^MANIFEST\.SKIP$
   CVS
 
-See the L</distcheck> and L</skipcheck> actions if you want to find out
+See the L<distcheck> and L<skipcheck> actions if you want to find out
 what the C<manifest> action would do, without actually doing anything.
 
-=item manifest_skip
-
-[version 0.3608]
-
-This is an action intended for use by module authors, not people
-installing modules.  It will generate a boilerplate MANIFEST.SKIP file
-if one does not already exist.
-
 =item manpages
 
 [version 0.28]
@@ -465,15 +466,6 @@ also supply or override install paths by specifying there values on
 the command line with the C<bindoc> and C<libdoc> installation
 targets.
 
-=item pardist
-
-[version 0.2806]
-
-Generates a PAR binary distribution for use with L<PAR> or L<PAR::Dist>.
-
-It requires that the PAR::Dist module (version 0.17 and up) is
-installed on your system.
-
 =item ppd
 
 [version 0.20]
@@ -481,7 +473,7 @@ installed on your system.
 Build a PPD file for your distribution.
 
 This action takes an optional argument C<codebase> which is used in
-the generated PPD file to specify the (usually relative) URL of the
+the generated ppd file to specify the (usually relative) URL of the
 distribution.  By default, this value is the distribution name without
 any path information.
 
@@ -494,21 +486,13 @@ Example:
 [version 0.23]
 
 Generates a PPM binary distribution and a PPD description file.  This
-action also invokes the C<ppd> action, so it can accept the same
+action also invokes the 'ppd' action, so it can accept the same
 C<codebase> argument described under that action.
 
 This uses the same mechanism as the C<dist> action to tar & zip its
 output, so you can supply C<tar> and/or C<gzip> parameters to affect
 the result.
 
-=item prereq_data
-
-[version 0.32]
-
-This action prints out a Perl data structure of all prerequisites and the versions
-required.  The output can be loaded again using C<eval()>.  This can be useful for
-external tools that wish to query a Build script for prerequisites.
-
 =item prereq_report
 
 [version 0.28]
@@ -523,7 +507,7 @@ for a bug report.
 [version 0.28]
 
 This action is identical to the C<install> action.  In the future,
-though, when C<install> starts writing to the file
+though, if C<install> starts writing to the file file
 F<$(INSTALLARCHLIB)/perllocal.pod>, C<pure_install> won't, and that
 will be the only difference between them.
 
@@ -552,16 +536,16 @@ distribution still pass the old regression tests, and so on.
 [version 0.05]
 
 Reports which files are skipped due to the entries in the
-F<MANIFEST.SKIP> file (See L</manifest> for details)
+F<MANIFEST.SKIP> file (See L<manifest> for details)
 
 =item test
 
 [version 0.01]
 
-This will use C<Test::Harness> or C<TAP::Harness> to run any regression
-tests and report their results. Tests can be defined in the standard
-places: a file called C<test.pl> in the top-level directory, or several
-files ending with C<.t> in a C<t/> directory.
+This will use C<Test::Harness> to run any regression tests and report
+their results.  Tests can be defined in the standard places: a file
+called C<test.pl> in the top-level directory, or several files ending
+with C<.t> in a C<t/> directory.
 
 If you want tests to be 'verbose', i.e. show details of test execution
 rather than just summary information, pass the argument C<verbose=1>.
@@ -569,14 +553,6 @@ rather than just summary information, pass the argument C<verbose=1>.
 If you want to run tests under the perl debugger, pass the argument
 C<debugger=1>.
 
-If you want to have Module::Build find test files with different file
-name extensions, pass the C<test_file_exts> argument with an array
-of extensions, such as C<[qw( .t .s .z )]>.
-
-If you want test to be run by C<TAP::Harness>, rather than C<Test::Harness>,
-pass the argument C<tap_harness_args> as an array reference of arguments to
-pass to the TAP::Harness constructor.
-
 In addition, if a file called C<visual.pl> exists in the top-level
 directory, this file will be executed as a Perl script and its output
 will be shown to the user.  This is a good place to put speed tests or
@@ -597,33 +573,6 @@ or use a C<glob()>-style pattern:
 
   ./Build test --test_files 't/01-*.t'
 
-=item testall
-
-[version 0.2807]
-
-[Note: the 'testall' action and the code snippets below are currently
-in alpha stage, see
-L<http://www.nntp.perl.org/group/perl.module.build/2007/03/msg584.html> ]
-
-Runs the C<test> action plus each of the C<test$type> actions defined by
-the keys of the C<test_types> parameter.
-
-Currently, you need to define the ACTION_test$type method yourself and
-enumerate them in the test_types parameter.
-
-  my $mb = Module::Build->subclass(
-    code => q(
-      sub ACTION_testspecial { shift->generic_test(type => 'special'); }
-      sub ACTION_testauthor  { shift->generic_test(type => 'author'); }
-    )
-  )->new(
-    ...
-    test_types  => {
-      special => '.st',
-      author  => ['.at', '.pt' ],
-    },
-    ...
-
 =item testcover
 
 [version 0.26]
@@ -648,7 +597,7 @@ argument.
 
 [version 0.25]
 
-This checks all the files described in the C<docs> action and
+This checks all the files described in the C<docs> action and 
 produces C<Test::Harness>-style output.  If you are a module author,
 this is useful to run before creating a new release.
 
@@ -656,7 +605,7 @@ this is useful to run before creating a new release.
 
 [version 0.28]
 
-This checks the pod coverage of the distribution and
+This checks the pod coverage of the distribution and 
 produces C<Test::Harness>-style output. If you are a module author,
 this is useful to run before creating a new release.
 
@@ -681,7 +630,7 @@ specify the C<versionlib> parameter when you run the C<Build.PL> script:
   perl Build.PL --versionlib /my/version/place/
 
 To override which version the module is installed as, specify the
-C<version> parameter when you run the C<Build.PL> script:
+C<versionlib> parameter when you run the C<Build.PL> script:
 
   perl Build.PL --version 0.50
 
@@ -703,9 +652,9 @@ respective action.
 NOTE: There is some preliminary support for options to use the more
 familiar long option style.  Most options can be preceded with the
 C<--> long option prefix, and the underscores changed to dashes
-(e.g. C<--use-rcfile>).  Additionally, the argument to boolean options is
+(e.g. --use-rcfile).  Additionally, the argument to boolean options is
 optional, and boolean options can be negated by prefixing them with
-C<no> or C<no-> (e.g. C<--noverbose> or C<--no-verbose>).
+'no' or 'no-' (e.g. --noverbose or --no-verbose).
 
 =over 4
 
@@ -713,43 +662,32 @@ C<no> or C<no-> (e.g. C<--noverbose> or C<--no-verbose>).
 
 Suppress informative messages on output.
 
-=item verbose
-
-Display extra information about the Build on output.  C<verbose> will
-turn off C<quiet>
-
-=item cpan_client
-
-Sets the C<cpan_client> command for use with the C<installdeps> action.
-See C<installdeps> for more details.
-
 =item use_rcfile
 
 Load the F<~/.modulebuildrc> option file.  This option can be set to
 false to prevent the custom resource file from being loaded.
 
+=item verbose
+
+Display extra information about the Build on output.
+
 =item allow_mb_mismatch
 
 Suppresses the check upon startup that the version of Module::Build
 we're now running under is the same version that was initially invoked
 when building the distribution (i.e. when the C<Build.PL> script was
-first run).  As of 0.3601, a mismatch results in a warning instead of
-a fatal error, so this option effectively just suppresses the warning.
-
-=item debug
-
-Prints Module::Build debugging information to STDOUT, such as a trace of
-executed build actions.
+first run).  Use with caution.
 
 =back
 
+
 =head2 Default Options File (F<.modulebuildrc>)
 
 [version 0.28]
 
 When Module::Build starts up, it will look first for a file,
 F<$ENV{HOME}/.modulebuildrc>.  If it's not found there, it will look
-in the F<.modulebuildrc> file in the directories referred to by
+in the the F<.modulebuildrc> file in the directories referred to by
 the environment variables C<HOMEDRIVE> + C<HOMEDIR>, C<USERPROFILE>,
 C<APPDATA>, C<WINDIR>, C<SYS$LOGIN>.  If the file exists, the options
 specified there will be used as defaults, as if they were typed on the
@@ -770,35 +708,15 @@ key C<*> (asterisk) denotes any global options that should be applied
 to all actions, and the key 'Build_PL' specifies options to be applied
 when you invoke C<perl Build.PL>.
 
-  *           verbose=1   # global options
-  diff        flags=-u
-  install     --install_base /home/ken
-              --install_path html=/home/ken/docs/html
-  installdeps --cpan_client 'cpanp -i'
+  *        verbose=1   # global options
+  diff     flags=-u
+  install  --install_base /home/ken
+           --install_path html=/home/ken/docs/html
 
 If you wish to locate your resource file in a different location, you
-can set the environment variable C<MODULEBUILDRC> to the complete
+can set the environment variable 'MODULEBUILDRC' to the complete
 absolute path of the file containing your options.
 
-=head2 Environment variables
-
-=over
-
-=item MODULEBUILDRC
-
-[version 0.28]
-
-Specifies an alternate location for a default options file as described above.
-
-=item PERL_MB_OPT
-
-[version 0.36]
-
-Command line options that are applied to Build.PL or any Build action.  The
-string is split as the shell would (e.g. whitespace) and the result is
-prepended to any actual command-line arguments.
-
-=back
 
 =head1 INSTALL PATHS
 
@@ -825,7 +743,7 @@ Usually pure-Perl module files ending in F<.pm>.
 =item arch
 
 "Architecture-dependent" module files, usually produced by compiling
-XS, L<Inline>, or similar code.
+XS, Inline, or similar code.
 
 =item script
 
@@ -853,11 +771,11 @@ pages belonging to the 'man3' category.
 
 =item binhtml
 
-This is the same as C<bindoc> above, but applies to HTML documents.
+This is the same as C<bindoc> above, but applies to html documents.
 
 =item libhtml
 
-This is the same as C<libdoc> above, but applies to HTML documents.
+This is the same as C<bindoc> above, but applies to html documents.
 
 =back
 
@@ -880,14 +798,14 @@ parameter as follows:
 
   lib     => installprivlib  installsitelib      installvendorlib
   arch    => installarchlib  installsitearch     installvendorarch
-  script  => installscript   installsitescript   installvendorscript
+  script  => installscript   installsitebin      installvendorbin
   bin     => installbin      installsitebin      installvendorbin
   bindoc  => installman1dir  installsiteman1dir  installvendorman1dir
   libdoc  => installman3dir  installsiteman3dir  installvendorman3dir
   binhtml => installhtml1dir installsitehtml1dir installvendorhtml1dir [*]
   libhtml => installhtml3dir installsitehtml3dir installvendorhtml3dir [*]
 
-  * Under some OS (eg. MSWin32) the destination for HTML documents is
+  * Under some OS (eg. MSWin32) the destination for html documents is
     determined by the C<Config.pm> entry C<installhtmldir>.
 
 The default value of C<installdirs> is "site".  If you're creating
@@ -905,7 +823,7 @@ with perl itself (i.e. a "core module"), then you may set
 C<installdirs> to "core" to overwrite the module in its present
 location.
 
-(Note that the 'script' line is different from C<MakeMaker> -
+(Note that the 'script' line is different from MakeMaker -
 unfortunately there's no such thing as "installsitescript" or
 "installvendorscript" entry in C<Config.pm>, so we use the
 "installsitebin" and "installvendorbin" entries to at least get the
@@ -940,8 +858,9 @@ system, you'll install as follows:
   binhtml => /home/ken/html
   libhtml => /home/ken/html
 
-Note that this is I<different> from how C<MakeMaker>'s C<PREFIX>
-parameter works.  C<install_base> just gives you a default layout under the
+Note that this is I<different> from how MakeMaker's C<PREFIX>
+parameter works.  See L</"Why PREFIX is not recommended"> for more
+details.  C<install_base> just gives you a default layout under the
 directory you specify, which may have little to do with the
 C<installdirs=site> layout.
 
@@ -968,82 +887,96 @@ platform you're installing on.
 
 =item prefix
 
-Provided for compatibility with C<ExtUtils::MakeMaker>'s PREFIX argument.
-C<prefix> should be used when you want Module::Build to install your
-modules, documentation, and scripts in the same place as
-C<ExtUtils::MakeMaker>'s PREFIX mechanism.
+Provided for compatibility with ExtUtils::MakeMaker's PREFIX argument.
+C<prefix> should be used when you wish Module::Build to install your
+modules, documentation and scripts in the same place
+ExtUtils::MakeMaker does.
 
 The following are equivalent.
 
     perl Build.PL --prefix /tmp/foo
     perl Makefile.PL PREFIX=/tmp/foo
 
-Because of the complex nature of the prefixification logic, the
-behavior of PREFIX in C<MakeMaker> has changed subtly over time.
+Because of the very complex nature of the prefixification logic, the
+behavior of PREFIX in MakeMaker has changed subtly over time.
 Module::Build's --prefix logic is equivalent to the PREFIX logic found
-in C<ExtUtils::MakeMaker> 6.30.
+in ExtUtils::MakeMaker 6.30.
 
-The maintainers of C<MakeMaker> do understand the troubles with the
-PREFIX mechanism, and added INSTALL_BASE support in version 6.31 of
-C<MakeMaker>, which was released in 2006.
-
-If you don't need to retain compatibility with old versions (pre-6.31) of C<ExtUtils::MakeMaker> or
-are starting a fresh Perl installation we recommend you use
-C<install_base> instead (and C<INSTALL_BASE> in C<ExtUtils::MakeMaker>).
-See L<Module::Build::Cookbook/Installing in the same location as
+If you do not need to retain compatibility with ExtUtils::MakeMaker or
+are starting a fresh Perl installation we recommand you use
+C<install_base> instead (and C<INSTALL_BASE> in ExtUtils::MakeMaker).
+See L<Module::Build::Cookbook/Instaling in the same location as
 ExtUtils::MakeMaker> for further information.
 
 
 =back
 
 
-=head1 COMPARISON
+=head1 MOTIVATIONS
 
-A comparison between C<Module::Build> and other CPAN distribution installers.
+There are several reasons I wanted to start over, and not just fix
+what I didn't like about MakeMaker:
 
-=over
+=over 4
 
 =item *
 
-L<ExtUtils::MakeMaker> requires C<make> and use of a F<Makefile>.
-C<Module::Build> does not, nor do other pure-perl installers following the
-F<Build.PL> spec such as L<Module::Build::Tiny>. In practice, this is usually
-not an issue for the end user, as C<make> is already required to install most
-CPAN modules, even on Windows.
+I don't like the core idea of MakeMaker, namely that C<make> should be
+involved in the build process.  Here are my reasons:
+
+=over 4
+
+=item +
+
+When a person is installing a Perl module, what can you assume about
+their environment?  Can you assume they have C<make>?  No, but you can
+assume they have some version of Perl.
+
+=item +
+
+When a person is writing a Perl module for intended distribution, can
+you assume that they know how to build a Makefile, so they can
+customize their build process?  No, but you can assume they know Perl,
+and could customize that way.
+
+=back
+
+For years, these things have been a barrier to people getting the
+build/install process to do what they want.
 
 =item *
 
-L<ExtUtils::MakeMaker> has been a core module in every version of Perl 5, and
-must maintain compatibility to install the majority of CPAN modules.
-C<Module::Build> was added to core in Perl 5.10 and removed from core in Perl
-5.20, and (like L<ExtUtils::MakeMaker>) is only updated to fix critical issues
-and maintain compatibility. C<Module::Build> and other non-core installers like
-L<Module::Build::Tiny> are installed from CPAN by declaring themselves as a
-C<configure> phase prerequisite, and in this way any installer can be used in
-place of L<ExtUtils::MakeMaker>.
+There are several architectural decisions in MakeMaker that make it
+very difficult to customize its behavior.  For instance, when using
+MakeMaker you do C<use ExtUtils::MakeMaker>, but the object created in
+C<WriteMakefile()> is actually blessed into a package name that's
+created on the fly, so you can't simply subclass
+C<ExtUtils::MakeMaker>.  There is a workaround C<MY> package that lets
+you override certain MakeMaker methods, but only certain explicitly
+preselected (by MakeMaker) methods can be overridden.  Also, the method
+of customization is very crude: you have to modify a string containing
+the Makefile text for the particular target.  Since these strings
+aren't documented, and I<can't> be documented (they take on different
+values depending on the platform, version of perl, version of
+MakeMaker, etc.), you have no guarantee that your modifications will
+work on someone else's machine or after an upgrade of MakeMaker or
+perl.
 
 =item *
 
-Customizing the build process with L<ExtUtils::MakeMaker> involves overriding
-certain methods that form the F<Makefile> by defining the subs in the C<MY::>
-namespace, requiring in-depth knowledge of F<Makefile>, but allowing targeted
-customization of the entire build. Customizing C<Module::Build> involves
-subclassing C<Module::Build> itself, adding or overriding pure-perl methods
-that represent build actions, which are invoked as arguments passed to the
-generated C<./Build> script. This is a simpler concept but requires redefining
-the standard build actions to invoke your customizations.
-L<Module::Build::Tiny> does not allow for customization.
+It is risky to make major changes to MakeMaker, since it does so many
+things, is so important, and generally works.  C<Module::Build> is an
+entirely separate package so that I can work on it all I want, without
+worrying about backward compatibility.
 
 =item *
 
-C<Module::Build> provides more features and a better experience for distribution
-authors than L<ExtUtils::MakeMaker>. However, tools designed specifically for
-authoring, such as L<Dist::Zilla> and its spinoffs L<Dist::Milla> and
-L<Minilla>, provide these features and more, and generate a configure script
-(F<Makefile.PL>/F<Build.PL>) that will use any of the various installers
-separately on the end user side. L<App::ModuleBuildTiny> is an alternative
-standalone authoring tool for distributions using L<Module::Build::Tiny>, which
-requires only a simple two-line F<Build.PL>.
+Finally, Perl is said to be a language for system administration.
+Could it really be the case that Perl isn't up to the task of building
+and installing software?  Even if that software is a bunch of stupid
+little C<.pm> files that just need to be copied from one place to
+another?  My sense was that we could design a system to accomplish
+this in a flexible, extensible, and friendly manner.  Or die trying.
 
 =back
 
@@ -1070,13 +1003,13 @@ Module-Build mailing list at <module-build@perl.org>.
 Bug reports are also welcome at
 <http://rt.cpan.org/NoAuth/Bugs.html?Dist=Module-Build>.
 
-The latest development version is available from the Git
-repository at <https://github.com/Perl-Toolchain-Gang/Module-Build>
+The latest development version is available from the Subversion
+repository at <https://svn.perl.org/modules/Module-Build/trunk/>
 
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2006 Ken Williams.  All rights reserved.
+Copyright (c) 2001-2005 Ken Williams.  All rights reserved.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -1084,11 +1017,11 @@ modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-perl(1), L<Module::Build::Cookbook>, L<Module::Build::Authoring>,
-L<Module::Build::API>, L<ExtUtils::MakeMaker>
+perl(1), L<Module::Build::Cookbook>(3), L<Module::Build::Authoring>(3),
+L<Module::Build::API>(3), L<ExtUtils::MakeMaker>(3), L<YAML>(3)
 
 F<META.yml> Specification:
-L<CPAN::Meta::Spec>
+L<http://module-build.sourceforge.net/META-spec-v1.2.html>
 
 L<http://www.dsmit.com/cons/>
 
